==> haskell-wai-3.2.1.1-30-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai
version: 3.2.1.1
id: wai-3.2.1.1-3tzqgorRVcHAGsgkI1Phfv
key: wai-3.2.1.1-3tzqgorRVcHAGsgkI1Phfv
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: https://github.com/yesodweb/wai
synopsis: Web Application Interface.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai Network.Wai.Internal
abi: 8299ae6c7ed09382e3eb0a11e9249ef2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-3.2.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-3.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-3.2.1.1
hs-libraries: HSwai-3.2.1.1-3tzqgorRVcHAGsgkI1Phfv
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA
    network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
    http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    vault-0.3.1.0-9ZML0jKNCF8K87yZXt3eZb
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA=46678a76449231ad37b0ff9566dd89ca
             network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT=3bb40bf00d3257de945a134963a298b0
             http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX=39fa7a400c896fb5d30c824d62823b68
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             vault-0.3.1.0-9ZML0jKNCF8K87yZXt3eZb=9dc4dd1d8e02333780a35dab851fe86b
haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html: /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-3.2.1.1-31-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai
version: 3.2.1.1
id: wai-3.2.1.1-EhoGHZwJBQOE7cOGGhN2UK
key: wai-3.2.1.1-EhoGHZwJBQOE7cOGGhN2UK
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: https://github.com/yesodweb/wai
synopsis: Web Application Interface.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai Network.Wai.Internal
abi: 031400cfbce6a7344af110315dc85fcf
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-3.2.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-3.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/wai-3.2.1.1
hs-libraries: HSwai-3.2.1.1-EhoGHZwJBQOE7cOGGhN2UK
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA
    network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT
    http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    vault-0.3.1.0-81QCypRRNkaHzxLwWgOdau
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             blaze-builder-0.4.0.2-IyhIxFYs3xU9dPk3t3umsA=46678a76449231ad37b0ff9566dd89ca
             network-2.6.3.4-9dk35Sk3nk1BI7Jw9SJICT=3bb40bf00d3257de945a134963a298b0
             http-types-0.9.1-L0SXZjYb79NLj6p0SwccQX=39fa7a400c896fb5d30c824d62823b68
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             vault-0.3.1.0-81QCypRRNkaHzxLwWgOdau=908b99e386dd6dfcfae3b19596f778c3
haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
haddock-html: /usr/share/doc/haskell-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
